<?php
/**
* @package phpBB Extension - Font Awesome BBCode
* @copyright (c) 2019 Sniper_E - http://sniper-e.com
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*/

namespace sniper\fontawesome\migrations;

class fontawesome_schema extends \phpbb\db\migration\migration
{
	public function update_data()
	{
		return array(
			// Add configs
			array('config.add', array('fontawesome_allow', 1)),
			array('config.add', array('fontawesome_color', 'background-image: linear-gradient(to top, green, orange, red) !important;-webkit-background-clip: text;color: transparent;')),
			array('config.add', array('fontawesome_value', 585)),
			array('config.add', array('fontawesome_width', 1920)),
			array('config.add', array('fontawesome_height', 1080)),
			array('config.add', array('fontawesome_version', '1.0.3')),

			// Insert BBcode
			array('custom', array(
				array(&$this, 'install_font_awesome_bbcodes'),
			)),

			// Insert sample data
			array('custom', array(
				array(&$this, 'insert_sample_data'),
			)),

			// Permission
			array('permission.add', array('u_use_font_awesome_bbcode', true)),
			// Set Permission
			array('permission.permission_set', array('ADMINISTRATORS', 'u_use_font_awesome_bbcode', 'group', true)),

			// ACP module
			['module.add', [
				'acp',
				'ACP_CAT_DOT_MODS',
				'ACP_FONTAWESOME_TITLE'
			]],
			['module.add', [
				'acp',
				'ACP_FONTAWESOME_TITLE',
				[
					'module_basename'	=> '\sniper\fontawesome\acp\acp_fontawesome_module',
				],
			]],
		);
	}

	public function update_schema()
	{
		return array(
			'add_tables'	=> array(
				$this->table_prefix . 'fontawesometable'	=> array(
					'COLUMNS'	=> array(
					'icon_id'	=> array('UINT', null, 'auto_increment'),
					'icon_name' => array('VCHAR', ''),
				),
				'PRIMARY_KEY' => 'icon_id',
			),
		));
	}

	public function revert_schema()
	{
		return array(
			'drop_tables'	=> array(
				$this->table_prefix . 'fontawesometable',
			),
		);
	}

	public function revert_data()
	{
		return array(
			array('custom', array(
				array(&$this, 'font_awesome_bbcodes_behind')
			)),
		);
	}

	public function font_awesome_bbcodes_behind($bbcode_tags)
	{
		$bbcode_tags = array('fa');

		$sql = 'UPDATE ' . BBCODES_TABLE . '
			SET display_on_posting = 0
			WHERE ' . $this->db->sql_in_set('bbcode_tag', $bbcode_tags);
		$this->db->sql_query($sql);
	}

	public function install_font_awesome_bbcodes($bbcode_data)
	{
		if (!class_exists('acp_bbcodes'))
		{
			include($this->phpbb_root_path . 'includes/acp/acp_bbcodes.' . $this->php_ext);
		}

		$bbcode_tool = new \acp_bbcodes();

		$bbcode_data = array(
			'fa' => array(
				'bbcode_match'		=> '[fa={IDENTIFIER1;optional}]{IDENTIFIER2;optional}[/fa]',
				'bbcode_tpl'		 => '<xsl:choose>
	<xsl:when test="@fa">
		<i class="icon fa-{IDENTIFIER2} fa-fw awesome_icon" title="fa-{IDENTIFIER2}" style="font-size: {IDENTIFIER1}px;color: {IDENTIFIER1}" aria-hidden="true"></i><span class="sr-only">fa-{IDENTIFIER2}</span>
	</xsl:when>
	<xsl:otherwise>
		<i class="icon fa-{IDENTIFIER2} fa-fw awesome_icon" title="fa-{IDENTIFIER2}" aria-hidden="true"></i><span class="sr-only">fa-{IDENTIFIER2}</span>
	</xsl:otherwise>
</xsl:choose>',
				'bbcode_helpline'	=> 'Font Awesome: [fa]glass[/fa] or size it [fa=45]coffee[/fa] or color it [fa=red]heart[/fa]',
				'display_on_posting' => 0,
			),
		);
		foreach ($bbcode_data as $bbcode_name => $bbcode_array)
		{
			$data = $bbcode_tool->build_regexp($bbcode_array['bbcode_match'], $bbcode_array['bbcode_tpl'], $bbcode_array['bbcode_helpline']);
			$bbcode_array += array(
				'bbcode_tag'			=> $data['bbcode_tag'],
				'first_pass_match'	=> $data['first_pass_match'],
				'first_pass_replace'	=> $data['first_pass_replace'],
				'second_pass_match'	=> $data['second_pass_match'],
				'second_pass_replace' => $data['second_pass_replace']
			);

			$sql = 'SELECT bbcode_id
				FROM ' . BBCODES_TABLE . "
				WHERE LOWER(bbcode_tag) = '" . strtolower($bbcode_name) . "'
				OR LOWER(bbcode_tag) = '" . strtolower($bbcode_array['bbcode_tag']) . "'";
			$result = $this->db->sql_query($sql);
			$row_exists = $this->db->sql_fetchrow($result);
			$this->db->sql_freeresult($result);

			if ($row_exists)
			{
				$bbcode_id = $row_exists['bbcode_id'];
				$sql = 'UPDATE ' . BBCODES_TABLE . '
					SET ' . $this->db->sql_build_array('UPDATE', $bbcode_array) . '
					WHERE bbcode_id = ' . $bbcode_id;
				$this->db->sql_query($sql);
			}
			else
			{
				$sql = 'SELECT MAX(bbcode_id) AS max_bbcode_id
					FROM ' . BBCODES_TABLE;
				$result = $this->db->sql_query($sql);
				$max_bbcode_id = $this->db->sql_fetchfield('max_bbcode_id');
				$this->db->sql_freeresult($result);

				if ($max_bbcode_id)
				{
					$bbcode_id = $max_bbcode_id + 1;

					if ($bbcode_id <= NUM_CORE_BBCODES)
					{
						$bbcode_id = NUM_CORE_BBCODES + 1;
					}
				}
				else
				{
					$bbcode_id = NUM_CORE_BBCODES + 1;
				}

				if ($bbcode_id <= BBCODE_LIMIT)
				{
					$bbcode_array['bbcode_id'] = (int) $bbcode_id;
					$bbcode_array['display_on_posting'] = ((int) $bbcode_array['display_on_posting']);
					$this->db->sql_query('INSERT INTO ' . BBCODES_TABLE . ' ' . $this->db->sql_build_array('INSERT', $bbcode_array));
				}
			}
		}
	}

	public function insert_sample_data()
	{
		if ($this->db_tools->sql_table_exists($this->table_prefix . 'fontawesometable'))
		{
			$sql_ary = array(
				array( 'icon_id' => null, 'icon_name' => '500px', ),
				array( 'icon_id' => null, 'icon_name' => 'adjust', ),
				array( 'icon_id' => null, 'icon_name' => 'adn', ),
				array( 'icon_id' => null, 'icon_name' => 'align-center', ),
				array( 'icon_id' => null, 'icon_name' => 'align-justify', ),
				array( 'icon_id' => null, 'icon_name' => 'align-left', ),
				array( 'icon_id' => null, 'icon_name' => 'align-right', ),
				array( 'icon_id' => null, 'icon_name' => 'amazon', ),
				array( 'icon_id' => null, 'icon_name' => 'ambulance', ),
				array( 'icon_id' => null, 'icon_name' => 'anchor', ),
				array( 'icon_id' => null, 'icon_name' => 'android', ),
				array( 'icon_id' => null, 'icon_name' => 'angellist', ),
				array( 'icon_id' => null, 'icon_name' => 'angle-double-down', ),
				array( 'icon_id' => null, 'icon_name' => 'angle-double-left', ),
				array( 'icon_id' => null, 'icon_name' => 'angle-double-right', ),
				array( 'icon_id' => null, 'icon_name' => 'angle-double-up', ),
				array( 'icon_id' => null, 'icon_name' => 'angle-down', ),
				array( 'icon_id' => null, 'icon_name' => 'angle-left', ),
				array( 'icon_id' => null, 'icon_name' => 'angle-right', ),
				array( 'icon_id' => null, 'icon_name' => 'angle-up', ),
				array( 'icon_id' => null, 'icon_name' => 'apple', ),
				array( 'icon_id' => null, 'icon_name' => 'archive', ),
				array( 'icon_id' => null, 'icon_name' => 'area-chart', ),
				array( 'icon_id' => null, 'icon_name' => 'arrow-circle-down', ),
				array( 'icon_id' => null, 'icon_name' => 'arrow-circle-left', ),
				array( 'icon_id' => null, 'icon_name' => 'arrow-circle-o-down', ),
				array( 'icon_id' => null, 'icon_name' => 'arrow-circle-o-left', ),
				array( 'icon_id' => null, 'icon_name' => 'arrow-circle-o-right', ),
				array( 'icon_id' => null, 'icon_name' => 'arrow-circle-o-up', ),
				array( 'icon_id' => null, 'icon_name' => 'arrow-circle-right', ),
				array( 'icon_id' => null, 'icon_name' => 'arrow-circle-up', ),
				array( 'icon_id' => null, 'icon_name' => 'arrow-down', ),
				array( 'icon_id' => null, 'icon_name' => 'arrow-left', ),
				array( 'icon_id' => null, 'icon_name' => 'arrow-right', ),
				array( 'icon_id' => null, 'icon_name' => 'arrow-up', ),
				array( 'icon_id' => null, 'icon_name' => 'arrows', ),
				array( 'icon_id' => null, 'icon_name' => 'arrows-alt', ),
				array( 'icon_id' => null, 'icon_name' => 'arrows-h', ),
				array( 'icon_id' => null, 'icon_name' => 'arrows-v', ),
				array( 'icon_id' => null, 'icon_name' => 'asterisk', ),
				array( 'icon_id' => null, 'icon_name' => 'at', ),
				array( 'icon_id' => null, 'icon_name' => 'backward', ),
				array( 'icon_id' => null, 'icon_name' => 'balance-scale', ),
				array( 'icon_id' => null, 'icon_name' => 'ban', ),
				array( 'icon_id' => null, 'icon_name' => 'bar-chart', ),
				array( 'icon_id' => null, 'icon_name' => 'barcode', ),
				array( 'icon_id' => null, 'icon_name' => 'bars', ),
				array( 'icon_id' => null, 'icon_name' => 'battery-empty', ),
				array( 'icon_id' => null, 'icon_name' => 'battery-full', ),
				array( 'icon_id' => null, 'icon_name' => 'battery-half', ),
				array( 'icon_id' => null, 'icon_name' => 'battery-quarter', ),
				array( 'icon_id' => null, 'icon_name' => 'battery-three-quarters', ),
				array( 'icon_id' => null, 'icon_name' => 'bed', ),
				array( 'icon_id' => null, 'icon_name' => 'beer', ),
				array( 'icon_id' => null, 'icon_name' => 'behance', ),
				array( 'icon_id' => null, 'icon_name' => 'behance-square', ),
				array( 'icon_id' => null, 'icon_name' => 'bell', ),
				array( 'icon_id' => null, 'icon_name' => 'bell-o', ),
				array( 'icon_id' => null, 'icon_name' => 'bell-slash', ),
				array( 'icon_id' => null, 'icon_name' => 'bell-slash-o', ),
				array( 'icon_id' => null, 'icon_name' => 'bicycle', ),
				array( 'icon_id' => null, 'icon_name' => 'binoculars', ),
				array( 'icon_id' => null, 'icon_name' => 'birthday-cake', ),
				array( 'icon_id' => null, 'icon_name' => 'bitbucket', ),
				array( 'icon_id' => null, 'icon_name' => 'bitbucket-square', ),
				array( 'icon_id' => null, 'icon_name' => 'black-tie', ),
				array( 'icon_id' => null, 'icon_name' => 'bold', ),
				array( 'icon_id' => null, 'icon_name' => 'bolt', ),
				array( 'icon_id' => null, 'icon_name' => 'bomb', ),
				array( 'icon_id' => null, 'icon_name' => 'book', ),
				array( 'icon_id' => null, 'icon_name' => 'bookmark', ),
				array( 'icon_id' => null, 'icon_name' => 'bookmark-o', ),
				array( 'icon_id' => null, 'icon_name' => 'briefcase', ),
				array( 'icon_id' => null, 'icon_name' => 'btc', ),
				array( 'icon_id' => null, 'icon_name' => 'bug', ),
				array( 'icon_id' => null, 'icon_name' => 'building', ),
				array( 'icon_id' => null, 'icon_name' => 'building-o', ),
				array( 'icon_id' => null, 'icon_name' => 'bullhorn', ),
				array( 'icon_id' => null, 'icon_name' => 'bullseye', ),
				array( 'icon_id' => null, 'icon_name' => 'bus', ),
				array( 'icon_id' => null, 'icon_name' => 'buysellads', ),
				array( 'icon_id' => null, 'icon_name' => 'calculator', ),
				array( 'icon_id' => null, 'icon_name' => 'calendar', ),
				array( 'icon_id' => null, 'icon_name' => 'calendar-check-o', ),
				array( 'icon_id' => null, 'icon_name' => 'calendar-minus-o', ),
				array( 'icon_id' => null, 'icon_name' => 'calendar-o', ),
				array( 'icon_id' => null, 'icon_name' => 'calendar-plus-o', ),
				array( 'icon_id' => null, 'icon_name' => 'calendar-times-o', ),
				array( 'icon_id' => null, 'icon_name' => 'camera', ),
				array( 'icon_id' => null, 'icon_name' => 'camera-retro', ),
				array( 'icon_id' => null, 'icon_name' => 'car', ),
				array( 'icon_id' => null, 'icon_name' => 'caret-down', ),
				array( 'icon_id' => null, 'icon_name' => 'caret-left', ),
				array( 'icon_id' => null, 'icon_name' => 'caret-right', ),
				array( 'icon_id' => null, 'icon_name' => 'caret-square-o-down', ),
				array( 'icon_id' => null, 'icon_name' => 'caret-square-o-left', ),
				array( 'icon_id' => null, 'icon_name' => 'caret-square-o-right', ),
				array( 'icon_id' => null, 'icon_name' => 'caret-square-o-up', ),
				array( 'icon_id' => null, 'icon_name' => 'caret-up', ),
				array( 'icon_id' => null, 'icon_name' => 'cart-arrow-down', ),
				array( 'icon_id' => null, 'icon_name' => 'cart-plus', ),
				array( 'icon_id' => null, 'icon_name' => 'cc', ),
				array( 'icon_id' => null, 'icon_name' => 'cc-amex', ),
				array( 'icon_id' => null, 'icon_name' => 'cc-diners-club', ),
				array( 'icon_id' => null, 'icon_name' => 'cc-discover', ),
				array( 'icon_id' => null, 'icon_name' => 'cc-jcb', ),
				array( 'icon_id' => null, 'icon_name' => 'cc-mastercard', ),
				array( 'icon_id' => null, 'icon_name' => 'cc-paypal', ),
				array( 'icon_id' => null, 'icon_name' => 'cc-stripe', ),
				array( 'icon_id' => null, 'icon_name' => 'cc-visa', ),
				array( 'icon_id' => null, 'icon_name' => 'certificate', ),
				array( 'icon_id' => null, 'icon_name' => 'chain-broken', ),
				array( 'icon_id' => null, 'icon_name' => 'check', ),
				array( 'icon_id' => null, 'icon_name' => 'check-circle', ),
				array( 'icon_id' => null, 'icon_name' => 'check-circle-o', ),
				array( 'icon_id' => null, 'icon_name' => 'check-square', ),
				array( 'icon_id' => null, 'icon_name' => 'check-square-o', ),
				array( 'icon_id' => null, 'icon_name' => 'chevron-circle-down', ),
				array( 'icon_id' => null, 'icon_name' => 'chevron-circle-left', ),
				array( 'icon_id' => null, 'icon_name' => 'chevron-circle-right', ),
				array( 'icon_id' => null, 'icon_name' => 'chevron-circle-up', ),
				array( 'icon_id' => null, 'icon_name' => 'chevron-down', ),
				array( 'icon_id' => null, 'icon_name' => 'chevron-left', ),
				array( 'icon_id' => null, 'icon_name' => 'chevron-right', ),
				array( 'icon_id' => null, 'icon_name' => 'chevron-up', ),
				array( 'icon_id' => null, 'icon_name' => 'child', ),
				array( 'icon_id' => null, 'icon_name' => 'chrome', ),
				array( 'icon_id' => null, 'icon_name' => 'circle', ),
				array( 'icon_id' => null, 'icon_name' => 'circle-o', ),
				array( 'icon_id' => null, 'icon_name' => 'circle-o-notch', ),
				array( 'icon_id' => null, 'icon_name' => 'circle-thin', ),
				array( 'icon_id' => null, 'icon_name' => 'clipboard', ),
				array( 'icon_id' => null, 'icon_name' => 'clock-o', ),
				array( 'icon_id' => null, 'icon_name' => 'clone', ),
				array( 'icon_id' => null, 'icon_name' => 'cloud', ),
				array( 'icon_id' => null, 'icon_name' => 'cloud-download', ),
				array( 'icon_id' => null, 'icon_name' => 'cloud-upload', ),
				array( 'icon_id' => null, 'icon_name' => 'code', ),
				array( 'icon_id' => null, 'icon_name' => 'code-fork', ),
				array( 'icon_id' => null, 'icon_name' => 'codepen', ),
				array( 'icon_id' => null, 'icon_name' => 'coffee', ),
				array( 'icon_id' => null, 'icon_name' => 'cog', ),
				array( 'icon_id' => null, 'icon_name' => 'cogs', ),
				array( 'icon_id' => null, 'icon_name' => 'columns', ),
				array( 'icon_id' => null, 'icon_name' => 'comment', ),
				array( 'icon_id' => null, 'icon_name' => 'comment-o', ),
				array( 'icon_id' => null, 'icon_name' => 'commenting', ),
				array( 'icon_id' => null, 'icon_name' => 'commenting-o', ),
				array( 'icon_id' => null, 'icon_name' => 'comments', ),
				array( 'icon_id' => null, 'icon_name' => 'comments-o', ),
				array( 'icon_id' => null, 'icon_name' => 'compass', ),
				array( 'icon_id' => null, 'icon_name' => 'compress', ),
				array( 'icon_id' => null, 'icon_name' => 'connectdevelop', ),
				array( 'icon_id' => null, 'icon_name' => 'contao', ),
				array( 'icon_id' => null, 'icon_name' => 'copyright', ),
				array( 'icon_id' => null, 'icon_name' => 'creative-commons', ),
				array( 'icon_id' => null, 'icon_name' => 'credit-card', ),
				array( 'icon_id' => null, 'icon_name' => 'crop', ),
				array( 'icon_id' => null, 'icon_name' => 'crosshairs', ),
				array( 'icon_id' => null, 'icon_name' => 'css3', ),
				array( 'icon_id' => null, 'icon_name' => 'cube', ),
				array( 'icon_id' => null, 'icon_name' => 'cubes', ),
				array( 'icon_id' => null, 'icon_name' => 'cutlery', ),
				array( 'icon_id' => null, 'icon_name' => 'dashcube', ),
				array( 'icon_id' => null, 'icon_name' => 'database', ),
				array( 'icon_id' => null, 'icon_name' => 'delicious', ),
				array( 'icon_id' => null, 'icon_name' => 'desktop', ),
				array( 'icon_id' => null, 'icon_name' => 'deviantart', ),
				array( 'icon_id' => null, 'icon_name' => 'diamond', ),
				array( 'icon_id' => null, 'icon_name' => 'digg', ),
				array( 'icon_id' => null, 'icon_name' => 'dot-circle-o', ),
				array( 'icon_id' => null, 'icon_name' => 'download', ),
				array( 'icon_id' => null, 'icon_name' => 'dribbble', ),
				array( 'icon_id' => null, 'icon_name' => 'dropbox', ),
				array( 'icon_id' => null, 'icon_name' => 'drupal', ),
				array( 'icon_id' => null, 'icon_name' => 'eject', ),
				array( 'icon_id' => null, 'icon_name' => 'ellipsis-h', ),
				array( 'icon_id' => null, 'icon_name' => 'ellipsis-v', ),
				array( 'icon_id' => null, 'icon_name' => 'empire', ),
				array( 'icon_id' => null, 'icon_name' => 'envelope', ),
				array( 'icon_id' => null, 'icon_name' => 'envelope-o', ),
				array( 'icon_id' => null, 'icon_name' => 'envelope-square', ),
				array( 'icon_id' => null, 'icon_name' => 'eraser', ),
				array( 'icon_id' => null, 'icon_name' => 'eur', ),
				array( 'icon_id' => null, 'icon_name' => 'exchange', ),
				array( 'icon_id' => null, 'icon_name' => 'exclamation', ),
				array( 'icon_id' => null, 'icon_name' => 'exclamation-circle', ),
				array( 'icon_id' => null, 'icon_name' => 'exclamation-triangle', ),
				array( 'icon_id' => null, 'icon_name' => 'expand', ),
				array( 'icon_id' => null, 'icon_name' => 'expeditedssl', ),
				array( 'icon_id' => null, 'icon_name' => 'external-link', ),
				array( 'icon_id' => null, 'icon_name' => 'external-link-square', ),
				array( 'icon_id' => null, 'icon_name' => 'eye', ),
				array( 'icon_id' => null, 'icon_name' => 'eye-slash', ),
				array( 'icon_id' => null, 'icon_name' => 'eyedropper', ),
				array( 'icon_id' => null, 'icon_name' => 'facebook', ),
				array( 'icon_id' => null, 'icon_name' => 'facebook-official', ),
				array( 'icon_id' => null, 'icon_name' => 'facebook-square', ),
				array( 'icon_id' => null, 'icon_name' => 'fast-backward', ),
				array( 'icon_id' => null, 'icon_name' => 'fast-forward', ),
				array( 'icon_id' => null, 'icon_name' => 'fax', ),
				array( 'icon_id' => null, 'icon_name' => 'female', ),
				array( 'icon_id' => null, 'icon_name' => 'fighter-jet', ),
				array( 'icon_id' => null, 'icon_name' => 'file', ),
				array( 'icon_id' => null, 'icon_name' => 'file-archive-o', ),
				array( 'icon_id' => null, 'icon_name' => 'file-audio-o', ),
				array( 'icon_id' => null, 'icon_name' => 'file-code-o', ),
				array( 'icon_id' => null, 'icon_name' => 'file-excel-o', ),
				array( 'icon_id' => null, 'icon_name' => 'file-image-o', ),
				array( 'icon_id' => null, 'icon_name' => 'file-o', ),
				array( 'icon_id' => null, 'icon_name' => 'file-pdf-o', ),
				array( 'icon_id' => null, 'icon_name' => 'file-powerpoint-o', ),
				array( 'icon_id' => null, 'icon_name' => 'file-text', ),
				array( 'icon_id' => null, 'icon_name' => 'file-text-o', ),
				array( 'icon_id' => null, 'icon_name' => 'file-video-o', ),
				array( 'icon_id' => null, 'icon_name' => 'file-word-o', ),
				array( 'icon_id' => null, 'icon_name' => 'files-o', ),
				array( 'icon_id' => null, 'icon_name' => 'film', ),
				array( 'icon_id' => null, 'icon_name' => 'filter', ),
				array( 'icon_id' => null, 'icon_name' => 'fire', ),
				array( 'icon_id' => null, 'icon_name' => 'fire-extinguisher', ),
				array( 'icon_id' => null, 'icon_name' => 'firefox', ),
				array( 'icon_id' => null, 'icon_name' => 'flag', ),
				array( 'icon_id' => null, 'icon_name' => 'flag-checkered', ),
				array( 'icon_id' => null, 'icon_name' => 'flag-o', ),
				array( 'icon_id' => null, 'icon_name' => 'flask', ),
				array( 'icon_id' => null, 'icon_name' => 'flickr', ),
				array( 'icon_id' => null, 'icon_name' => 'floppy-o', ),
				array( 'icon_id' => null, 'icon_name' => 'folder', ),
				array( 'icon_id' => null, 'icon_name' => 'folder-o', ),
				array( 'icon_id' => null, 'icon_name' => 'folder-open', ),
				array( 'icon_id' => null, 'icon_name' => 'folder-open-o', ),
				array( 'icon_id' => null, 'icon_name' => 'font', ),
				array( 'icon_id' => null, 'icon_name' => 'fonticons', ),
				array( 'icon_id' => null, 'icon_name' => 'forumbee', ),
				array( 'icon_id' => null, 'icon_name' => 'forward', ),
				array( 'icon_id' => null, 'icon_name' => 'foursquare', ),
				array( 'icon_id' => null, 'icon_name' => 'frown-o', ),
				array( 'icon_id' => null, 'icon_name' => 'futbol-o', ),
				array( 'icon_id' => null, 'icon_name' => 'gamepad', ),
				array( 'icon_id' => null, 'icon_name' => 'gavel', ),
				array( 'icon_id' => null, 'icon_name' => 'gbp', ),
				array( 'icon_id' => null, 'icon_name' => 'genderless', ),
				array( 'icon_id' => null, 'icon_name' => 'get-pocket', ),
				array( 'icon_id' => null, 'icon_name' => 'gg', ),
				array( 'icon_id' => null, 'icon_name' => 'gg-circle', ),
				array( 'icon_id' => null, 'icon_name' => 'gift', ),
				array( 'icon_id' => null, 'icon_name' => 'git', ),
				array( 'icon_id' => null, 'icon_name' => 'git-square', ),
				array( 'icon_id' => null, 'icon_name' => 'github', ),
				array( 'icon_id' => null, 'icon_name' => 'github-alt', ),
				array( 'icon_id' => null, 'icon_name' => 'github-square', ),
				array( 'icon_id' => null, 'icon_name' => 'glass', ),
				array( 'icon_id' => null, 'icon_name' => 'globe', ),
				array( 'icon_id' => null, 'icon_name' => 'google', ),
				array( 'icon_id' => null, 'icon_name' => 'google-plus', ),
				array( 'icon_id' => null, 'icon_name' => 'google-plus-square', ),
				array( 'icon_id' => null, 'icon_name' => 'google-wallet', ),
				array( 'icon_id' => null, 'icon_name' => 'graduation-cap', ),
				array( 'icon_id' => null, 'icon_name' => 'gratipay', ),
				array( 'icon_id' => null, 'icon_name' => 'h-square', ),
				array( 'icon_id' => null, 'icon_name' => 'hacker-news', ),
				array( 'icon_id' => null, 'icon_name' => 'hand-lizard-o', ),
				array( 'icon_id' => null, 'icon_name' => 'hand-o-down', ),
				array( 'icon_id' => null, 'icon_name' => 'hand-o-left', ),
				array( 'icon_id' => null, 'icon_name' => 'hand-o-right', ),
				array( 'icon_id' => null, 'icon_name' => 'hand-o-up', ),
				array( 'icon_id' => null, 'icon_name' => 'hand-paper-o', ),
				array( 'icon_id' => null, 'icon_name' => 'hand-peace-o', ),
				array( 'icon_id' => null, 'icon_name' => 'hand-pointer-o', ),
				array( 'icon_id' => null, 'icon_name' => 'hand-rock-o', ),
				array( 'icon_id' => null, 'icon_name' => 'hand-scissors-o', ),
				array( 'icon_id' => null, 'icon_name' => 'hand-spock-o', ),
				array( 'icon_id' => null, 'icon_name' => 'hdd-o', ),
				array( 'icon_id' => null, 'icon_name' => 'header', ),
				array( 'icon_id' => null, 'icon_name' => 'headphones', ),
				array( 'icon_id' => null, 'icon_name' => 'heart', ),
				array( 'icon_id' => null, 'icon_name' => 'heart-o', ),
				array( 'icon_id' => null, 'icon_name' => 'heartbeat', ),
				array( 'icon_id' => null, 'icon_name' => 'history', ),
				array( 'icon_id' => null, 'icon_name' => 'home', ),
				array( 'icon_id' => null, 'icon_name' => 'hospital-o', ),
				array( 'icon_id' => null, 'icon_name' => 'hourglass', ),
				array( 'icon_id' => null, 'icon_name' => 'hourglass-end', ),
				array( 'icon_id' => null, 'icon_name' => 'hourglass-half', ),
				array( 'icon_id' => null, 'icon_name' => 'hourglass-o', ),
				array( 'icon_id' => null, 'icon_name' => 'hourglass-start', ),
				array( 'icon_id' => null, 'icon_name' => 'houzz', ),
				array( 'icon_id' => null, 'icon_name' => 'html5', ),
				array( 'icon_id' => null, 'icon_name' => 'i-cursor', ),
				array( 'icon_id' => null, 'icon_name' => 'ils', ),
				array( 'icon_id' => null, 'icon_name' => 'inbox', ),
				array( 'icon_id' => null, 'icon_name' => 'indent', ),
				array( 'icon_id' => null, 'icon_name' => 'industry', ),
				array( 'icon_id' => null, 'icon_name' => 'info', ),
				array( 'icon_id' => null, 'icon_name' => 'info-circle', ),
				array( 'icon_id' => null, 'icon_name' => 'inr', ),
				array( 'icon_id' => null, 'icon_name' => 'instagram', ),
				array( 'icon_id' => null, 'icon_name' => 'internet-explorer', ),
				array( 'icon_id' => null, 'icon_name' => 'ioxhost', ),
				array( 'icon_id' => null, 'icon_name' => 'italic', ),
				array( 'icon_id' => null, 'icon_name' => 'joomla', ),
				array( 'icon_id' => null, 'icon_name' => 'jpy', ),
				array( 'icon_id' => null, 'icon_name' => 'jsfiddle', ),
				array( 'icon_id' => null, 'icon_name' => 'key', ),
				array( 'icon_id' => null, 'icon_name' => 'keyboard-o', ),
				array( 'icon_id' => null, 'icon_name' => 'krw', ),
				array( 'icon_id' => null, 'icon_name' => 'language', ),
				array( 'icon_id' => null, 'icon_name' => 'laptop', ),
				array( 'icon_id' => null, 'icon_name' => 'lastfm', ),
				array( 'icon_id' => null, 'icon_name' => 'lastfm-square', ),
				array( 'icon_id' => null, 'icon_name' => 'leaf', ),
				array( 'icon_id' => null, 'icon_name' => 'leanpub', ),
				array( 'icon_id' => null, 'icon_name' => 'lemon-o', ),
				array( 'icon_id' => null, 'icon_name' => 'level-down', ),
				array( 'icon_id' => null, 'icon_name' => 'level-up', ),
				array( 'icon_id' => null, 'icon_name' => 'life-ring', ),
				array( 'icon_id' => null, 'icon_name' => 'lightbulb-o', ),
				array( 'icon_id' => null, 'icon_name' => 'line-chart', ),
				array( 'icon_id' => null, 'icon_name' => 'link', ),
				array( 'icon_id' => null, 'icon_name' => 'linkedin', ),
				array( 'icon_id' => null, 'icon_name' => 'linkedin-square', ),
				array( 'icon_id' => null, 'icon_name' => 'linux', ),
				array( 'icon_id' => null, 'icon_name' => 'list', ),
				array( 'icon_id' => null, 'icon_name' => 'list-alt', ),
				array( 'icon_id' => null, 'icon_name' => 'list-ol', ),
				array( 'icon_id' => null, 'icon_name' => 'list-ul', ),
				array( 'icon_id' => null, 'icon_name' => 'location-arrow', ),
				array( 'icon_id' => null, 'icon_name' => 'lock', ),
				array( 'icon_id' => null, 'icon_name' => 'long-arrow-down', ),
				array( 'icon_id' => null, 'icon_name' => 'long-arrow-left', ),
				array( 'icon_id' => null, 'icon_name' => 'long-arrow-right', ),
				array( 'icon_id' => null, 'icon_name' => 'long-arrow-up', ),
				array( 'icon_id' => null, 'icon_name' => 'magic', ),
				array( 'icon_id' => null, 'icon_name' => 'magnet', ),
				array( 'icon_id' => null, 'icon_name' => 'male', ),
				array( 'icon_id' => null, 'icon_name' => 'map', ),
				array( 'icon_id' => null, 'icon_name' => 'map-marker', ),
				array( 'icon_id' => null, 'icon_name' => 'map-o', ),
				array( 'icon_id' => null, 'icon_name' => 'map-pin', ),
				array( 'icon_id' => null, 'icon_name' => 'map-signs', ),
				array( 'icon_id' => null, 'icon_name' => 'mars', ),
				array( 'icon_id' => null, 'icon_name' => 'mars-double', ),
				array( 'icon_id' => null, 'icon_name' => 'mars-stroke', ),
				array( 'icon_id' => null, 'icon_name' => 'mars-stroke-h', ),
				array( 'icon_id' => null, 'icon_name' => 'mars-stroke-v', ),
				array( 'icon_id' => null, 'icon_name' => 'maxcdn', ),
				array( 'icon_id' => null, 'icon_name' => 'meanpath', ),
				array( 'icon_id' => null, 'icon_name' => 'medium', ),
				array( 'icon_id' => null, 'icon_name' => 'medkit', ),
				array( 'icon_id' => null, 'icon_name' => 'meh-o', ),
				array( 'icon_id' => null, 'icon_name' => 'mercury', ),
				array( 'icon_id' => null, 'icon_name' => 'microphone', ),
				array( 'icon_id' => null, 'icon_name' => 'microphone-slash', ),
				array( 'icon_id' => null, 'icon_name' => 'minus', ),
				array( 'icon_id' => null, 'icon_name' => 'minus-circle', ),
				array( 'icon_id' => null, 'icon_name' => 'minus-square', ),
				array( 'icon_id' => null, 'icon_name' => 'minus-square-o', ),
				array( 'icon_id' => null, 'icon_name' => 'mobile', ),
				array( 'icon_id' => null, 'icon_name' => 'money', ),
				array( 'icon_id' => null, 'icon_name' => 'moon-o', ),
				array( 'icon_id' => null, 'icon_name' => 'motorcycle', ),
				array( 'icon_id' => null, 'icon_name' => 'mouse-pointer', ),
				array( 'icon_id' => null, 'icon_name' => 'music', ),
				array( 'icon_id' => null, 'icon_name' => 'neuter', ),
				array( 'icon_id' => null, 'icon_name' => 'newspaper-o', ),
				array( 'icon_id' => null, 'icon_name' => 'object-group', ),
				array( 'icon_id' => null, 'icon_name' => 'object-ungroup', ),
				array( 'icon_id' => null, 'icon_name' => 'odnoklassniki', ),
				array( 'icon_id' => null, 'icon_name' => 'odnoklassniki-square', ),
				array( 'icon_id' => null, 'icon_name' => 'opencart', ),
				array( 'icon_id' => null, 'icon_name' => 'openid', ),
				array( 'icon_id' => null, 'icon_name' => 'opera', ),
				array( 'icon_id' => null, 'icon_name' => 'optin-monster', ),
				array( 'icon_id' => null, 'icon_name' => 'outdent', ),
				array( 'icon_id' => null, 'icon_name' => 'pagelines', ),
				array( 'icon_id' => null, 'icon_name' => 'paint-brush', ),
				array( 'icon_id' => null, 'icon_name' => 'paper-plane', ),
				array( 'icon_id' => null, 'icon_name' => 'paper-plane-o', ),
				array( 'icon_id' => null, 'icon_name' => 'paperclip', ),
				array( 'icon_id' => null, 'icon_name' => 'paragraph', ),
				array( 'icon_id' => null, 'icon_name' => 'pause', ),
				array( 'icon_id' => null, 'icon_name' => 'paw', ),
				array( 'icon_id' => null, 'icon_name' => 'paypal', ),
				array( 'icon_id' => null, 'icon_name' => 'pencil', ),
				array( 'icon_id' => null, 'icon_name' => 'pencil-square', ),
				array( 'icon_id' => null, 'icon_name' => 'pencil-square-o', ),
				array( 'icon_id' => null, 'icon_name' => 'phone', ),
				array( 'icon_id' => null, 'icon_name' => 'phone-square', ),
				array( 'icon_id' => null, 'icon_name' => 'picture-o', ),
				array( 'icon_id' => null, 'icon_name' => 'pie-chart', ),
				array( 'icon_id' => null, 'icon_name' => 'pied-piper', ),
				array( 'icon_id' => null, 'icon_name' => 'pied-piper-alt', ),
				array( 'icon_id' => null, 'icon_name' => 'pinterest', ),
				array( 'icon_id' => null, 'icon_name' => 'pinterest-p', ),
				array( 'icon_id' => null, 'icon_name' => 'pinterest-square', ),
				array( 'icon_id' => null, 'icon_name' => 'plane', ),
				array( 'icon_id' => null, 'icon_name' => 'play', ),
				array( 'icon_id' => null, 'icon_name' => 'play-circle', ),
				array( 'icon_id' => null, 'icon_name' => 'play-circle-o', ),
				array( 'icon_id' => null, 'icon_name' => 'plug', ),
				array( 'icon_id' => null, 'icon_name' => 'plus', ),
				array( 'icon_id' => null, 'icon_name' => 'plus-circle', ),
				array( 'icon_id' => null, 'icon_name' => 'plus-square', ),
				array( 'icon_id' => null, 'icon_name' => 'plus-square-o', ),
				array( 'icon_id' => null, 'icon_name' => 'power-off', ),
				array( 'icon_id' => null, 'icon_name' => 'print', ),
				array( 'icon_id' => null, 'icon_name' => 'puzzle-piece', ),
				array( 'icon_id' => null, 'icon_name' => 'qq', ),
				array( 'icon_id' => null, 'icon_name' => 'qrcode', ),
				array( 'icon_id' => null, 'icon_name' => 'question', ),
				array( 'icon_id' => null, 'icon_name' => 'question-circle', ),
				array( 'icon_id' => null, 'icon_name' => 'quote-left', ),
				array( 'icon_id' => null, 'icon_name' => 'quote-right', ),
				array( 'icon_id' => null, 'icon_name' => 'random', ),
				array( 'icon_id' => null, 'icon_name' => 'rebel', ),
				array( 'icon_id' => null, 'icon_name' => 'recycle', ),
				array( 'icon_id' => null, 'icon_name' => 'reddit', ),
				array( 'icon_id' => null, 'icon_name' => 'reddit-square', ),
				array( 'icon_id' => null, 'icon_name' => 'refresh', ),
				array( 'icon_id' => null, 'icon_name' => 'registered', ),
				array( 'icon_id' => null, 'icon_name' => 'renren', ),
				array( 'icon_id' => null, 'icon_name' => 'repeat', ),
				array( 'icon_id' => null, 'icon_name' => 'reply', ),
				array( 'icon_id' => null, 'icon_name' => 'reply-all', ),
				array( 'icon_id' => null, 'icon_name' => 'retweet', ),
				array( 'icon_id' => null, 'icon_name' => 'road', ),
				array( 'icon_id' => null, 'icon_name' => 'rocket', ),
				array( 'icon_id' => null, 'icon_name' => 'rss', ),
				array( 'icon_id' => null, 'icon_name' => 'rss-square', ),
				array( 'icon_id' => null, 'icon_name' => 'rub', ),
				array( 'icon_id' => null, 'icon_name' => 'safari', ),
				array( 'icon_id' => null, 'icon_name' => 'scissors', ),
				array( 'icon_id' => null, 'icon_name' => 'search', ),
				array( 'icon_id' => null, 'icon_name' => 'search-minus', ),
				array( 'icon_id' => null, 'icon_name' => 'search-plus', ),
				array( 'icon_id' => null, 'icon_name' => 'sellsy', ),
				array( 'icon_id' => null, 'icon_name' => 'server', ),
				array( 'icon_id' => null, 'icon_name' => 'share', ),
				array( 'icon_id' => null, 'icon_name' => 'share-alt', ),
				array( 'icon_id' => null, 'icon_name' => 'share-alt-square', ),
				array( 'icon_id' => null, 'icon_name' => 'share-square', ),
				array( 'icon_id' => null, 'icon_name' => 'share-square-o', ),
				array( 'icon_id' => null, 'icon_name' => 'shield', ),
				array( 'icon_id' => null, 'icon_name' => 'ship', ),
				array( 'icon_id' => null, 'icon_name' => 'shirtsinbulk', ),
				array( 'icon_id' => null, 'icon_name' => 'shopping-cart', ),
				array( 'icon_id' => null, 'icon_name' => 'sign-in', ),
				array( 'icon_id' => null, 'icon_name' => 'sign-out', ),
				array( 'icon_id' => null, 'icon_name' => 'signal', ),
				array( 'icon_id' => null, 'icon_name' => 'simplybuilt', ),
				array( 'icon_id' => null, 'icon_name' => 'sitemap', ),
				array( 'icon_id' => null, 'icon_name' => 'skyatlas', ),
				array( 'icon_id' => null, 'icon_name' => 'skype', ),
				array( 'icon_id' => null, 'icon_name' => 'slack', ),
				array( 'icon_id' => null, 'icon_name' => 'sliders', ),
				array( 'icon_id' => null, 'icon_name' => 'slideshare', ),
				array( 'icon_id' => null, 'icon_name' => 'smile-o', ),
				array( 'icon_id' => null, 'icon_name' => 'sort', ),
				array( 'icon_id' => null, 'icon_name' => 'sort-alpha-asc', ),
				array( 'icon_id' => null, 'icon_name' => 'sort-alpha-desc', ),
				array( 'icon_id' => null, 'icon_name' => 'sort-amount-asc', ),
				array( 'icon_id' => null, 'icon_name' => 'sort-amount-desc', ),
				array( 'icon_id' => null, 'icon_name' => 'sort-asc', ),
				array( 'icon_id' => null, 'icon_name' => 'sort-desc', ),
				array( 'icon_id' => null, 'icon_name' => 'sort-numeric-asc', ),
				array( 'icon_id' => null, 'icon_name' => 'sort-numeric-desc', ),
				array( 'icon_id' => null, 'icon_name' => 'soundcloud', ),
				array( 'icon_id' => null, 'icon_name' => 'space-shuttle', ),
				array( 'icon_id' => null, 'icon_name' => 'spinner', ),
				array( 'icon_id' => null, 'icon_name' => 'spoon', ),
				array( 'icon_id' => null, 'icon_name' => 'spotify', ),
				array( 'icon_id' => null, 'icon_name' => 'square', ),
				array( 'icon_id' => null, 'icon_name' => 'square-o', ),
				array( 'icon_id' => null, 'icon_name' => 'stack-exchange', ),
				array( 'icon_id' => null, 'icon_name' => 'stack-overflow', ),
				array( 'icon_id' => null, 'icon_name' => 'star', ),
				array( 'icon_id' => null, 'icon_name' => 'star-half', ),
				array( 'icon_id' => null, 'icon_name' => 'star-half-o', ),
				array( 'icon_id' => null, 'icon_name' => 'star-o', ),
				array( 'icon_id' => null, 'icon_name' => 'steam', ),
				array( 'icon_id' => null, 'icon_name' => 'steam-square', ),
				array( 'icon_id' => null, 'icon_name' => 'step-backward', ),
				array( 'icon_id' => null, 'icon_name' => 'step-forward', ),
				array( 'icon_id' => null, 'icon_name' => 'stethoscope', ),
				array( 'icon_id' => null, 'icon_name' => 'sticky-note', ),
				array( 'icon_id' => null, 'icon_name' => 'sticky-note-o', ),
				array( 'icon_id' => null, 'icon_name' => 'stop', ),
				array( 'icon_id' => null, 'icon_name' => 'street-view', ),
				array( 'icon_id' => null, 'icon_name' => 'strikethrough', ),
				array( 'icon_id' => null, 'icon_name' => 'stumbleupon', ),
				array( 'icon_id' => null, 'icon_name' => 'stumbleupon-circle', ),
				array( 'icon_id' => null, 'icon_name' => 'subscript', ),
				array( 'icon_id' => null, 'icon_name' => 'subway', ),
				array( 'icon_id' => null, 'icon_name' => 'suitcase', ),
				array( 'icon_id' => null, 'icon_name' => 'sun-o', ),
				array( 'icon_id' => null, 'icon_name' => 'superscript', ),
				array( 'icon_id' => null, 'icon_name' => 'table', ),
				array( 'icon_id' => null, 'icon_name' => 'tablet', ),
				array( 'icon_id' => null, 'icon_name' => 'tachometer', ),
				array( 'icon_id' => null, 'icon_name' => 'tag', ),
				array( 'icon_id' => null, 'icon_name' => 'tags', ),
				array( 'icon_id' => null, 'icon_name' => 'tasks', ),
				array( 'icon_id' => null, 'icon_name' => 'taxi', ),
				array( 'icon_id' => null, 'icon_name' => 'television', ),
				array( 'icon_id' => null, 'icon_name' => 'tencent-weibo', ),
				array( 'icon_id' => null, 'icon_name' => 'terminal', ),
				array( 'icon_id' => null, 'icon_name' => 'text-height', ),
				array( 'icon_id' => null, 'icon_name' => 'text-width', ),
				array( 'icon_id' => null, 'icon_name' => 'th', ),
				array( 'icon_id' => null, 'icon_name' => 'th-large', ),
				array( 'icon_id' => null, 'icon_name' => 'th-list', ),
				array( 'icon_id' => null, 'icon_name' => 'thumb-tack', ),
				array( 'icon_id' => null, 'icon_name' => 'thumbs-down', ),
				array( 'icon_id' => null, 'icon_name' => 'thumbs-o-down', ),
				array( 'icon_id' => null, 'icon_name' => 'thumbs-o-up', ),
				array( 'icon_id' => null, 'icon_name' => 'thumbs-up', ),
				array( 'icon_id' => null, 'icon_name' => 'ticket', ),
				array( 'icon_id' => null, 'icon_name' => 'times', ),
				array( 'icon_id' => null, 'icon_name' => 'times-circle', ),
				array( 'icon_id' => null, 'icon_name' => 'times-circle-o', ),
				array( 'icon_id' => null, 'icon_name' => 'tint', ),
				array( 'icon_id' => null, 'icon_name' => 'toggle-off', ),
				array( 'icon_id' => null, 'icon_name' => 'toggle-on', ),
				array( 'icon_id' => null, 'icon_name' => 'trademark', ),
				array( 'icon_id' => null, 'icon_name' => 'train', ),
				array( 'icon_id' => null, 'icon_name' => 'transgender', ),
				array( 'icon_id' => null, 'icon_name' => 'transgender-alt', ),
				array( 'icon_id' => null, 'icon_name' => 'trash', ),
				array( 'icon_id' => null, 'icon_name' => 'trash-o', ),
				array( 'icon_id' => null, 'icon_name' => 'tree', ),
				array( 'icon_id' => null, 'icon_name' => 'trello', ),
				array( 'icon_id' => null, 'icon_name' => 'tripadvisor', ),
				array( 'icon_id' => null, 'icon_name' => 'trophy', ),
				array( 'icon_id' => null, 'icon_name' => 'truck', ),
				array( 'icon_id' => null, 'icon_name' => 'try', ),
				array( 'icon_id' => null, 'icon_name' => 'tty', ),
				array( 'icon_id' => null, 'icon_name' => 'tumblr', ),
				array( 'icon_id' => null, 'icon_name' => 'tumblr-square', ),
				array( 'icon_id' => null, 'icon_name' => 'twitch', ),
				array( 'icon_id' => null, 'icon_name' => 'twitter', ),
				array( 'icon_id' => null, 'icon_name' => 'twitter-square', ),
				array( 'icon_id' => null, 'icon_name' => 'umbrella', ),
				array( 'icon_id' => null, 'icon_name' => 'underline', ),
				array( 'icon_id' => null, 'icon_name' => 'undo', ),
				array( 'icon_id' => null, 'icon_name' => 'university', ),
				array( 'icon_id' => null, 'icon_name' => 'unlock', ),
				array( 'icon_id' => null, 'icon_name' => 'unlock-alt', ),
				array( 'icon_id' => null, 'icon_name' => 'upload', ),
				array( 'icon_id' => null, 'icon_name' => 'usd', ),
				array( 'icon_id' => null, 'icon_name' => 'user', ),
				array( 'icon_id' => null, 'icon_name' => 'user-md', ),
				array( 'icon_id' => null, 'icon_name' => 'user-plus', ),
				array( 'icon_id' => null, 'icon_name' => 'user-secret', ),
				array( 'icon_id' => null, 'icon_name' => 'user-times', ),
				array( 'icon_id' => null, 'icon_name' => 'users', ),
				array( 'icon_id' => null, 'icon_name' => 'venus', ),
				array( 'icon_id' => null, 'icon_name' => 'venus-double', ),
				array( 'icon_id' => null, 'icon_name' => 'venus-mars', ),
				array( 'icon_id' => null, 'icon_name' => 'viacoin', ),
				array( 'icon_id' => null, 'icon_name' => 'video-camera', ),
				array( 'icon_id' => null, 'icon_name' => 'vimeo', ),
				array( 'icon_id' => null, 'icon_name' => 'vimeo-square', ),
				array( 'icon_id' => null, 'icon_name' => 'vine', ),
				array( 'icon_id' => null, 'icon_name' => 'vk', ),
				array( 'icon_id' => null, 'icon_name' => 'volume-down', ),
				array( 'icon_id' => null, 'icon_name' => 'volume-off', ),
				array( 'icon_id' => null, 'icon_name' => 'volume-up', ),
				array( 'icon_id' => null, 'icon_name' => 'weibo', ),
				array( 'icon_id' => null, 'icon_name' => 'weixin', ),
				array( 'icon_id' => null, 'icon_name' => 'whatsapp', ),
				array( 'icon_id' => null, 'icon_name' => 'wheelchair', ),
				array( 'icon_id' => null, 'icon_name' => 'wifi', ),
				array( 'icon_id' => null, 'icon_name' => 'wikipedia-w', ),
				array( 'icon_id' => null, 'icon_name' => 'windows', ),
				array( 'icon_id' => null, 'icon_name' => 'wordpress', ),
				array( 'icon_id' => null, 'icon_name' => 'wrench', ),
				array( 'icon_id' => null, 'icon_name' => 'xing', ),
				array( 'icon_id' => null, 'icon_name' => 'xing-square', ),
				array( 'icon_id' => null, 'icon_name' => 'y-combinator', ),
				array( 'icon_id' => null, 'icon_name' => 'yahoo', ),
				array( 'icon_id' => null, 'icon_name' => 'yelp', ),
				array( 'icon_id' => null, 'icon_name' => 'youtube', ),
				array( 'icon_id' => null, 'icon_name' => 'youtube-play', ),
				array( 'icon_id' => null, 'icon_name' => 'youtube-square', ),
			);
			$this->db->sql_multi_insert($this->table_prefix . 'fontawesometable', $sql_ary);
		}
	}
}
